@@ -1,6 +1,6 @@
 package Map::Tube::London;
 
-$Map::Tube::London::VERSION   = '0.91';
+$Map::Tube::London::VERSION   = '0.92';
 $Map::Tube::London::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::London - Interface to the London Tube Map.
 
 =head1 VERSION
 
-Version 0.91
+Version 0.92
 
 =cut
 
@@ -18,7 +18,7 @@ use Data::Dumper;
 use File::Share ':all';
 
 use Moo;
-use namespace::clean;
+use namespace::autoclean;
 
 has json => (is => 'ro', default => sub { return dist_file('Map-Tube-London', 'london-map.json') });
 has skip => (is => 'ro', default => sub { _skip(); });
